@@ -155,14 +155,6 @@ class OpenStackImagesShell(object):
                                  'of schema that generates portions of the '
                                  'help text. Ignored with API version 1.')
 
-        parser.add_argument('--no-ssl-compression',
-                            dest='ssl_compression',
-                            default=True, action='store_false',
-                            help='DEPRECATED! This option is deprecated '
-                                 'and not used anymore. SSL compression '
-                                 'should be disabled by default by the '
-                                 'system SSL library.')
-
         parser.add_argument('-f', '--force',
                             dest='force',
                             default=False, action='store_true',
@@ -192,16 +184,18 @@ class OpenStackImagesShell(object):
         if osprofiler_profiler:
             parser.add_argument('--profile',
                                 metavar='HMAC_KEY',
+                                default=utils.env('OS_PROFILE'),
                                 help='HMAC key to use for encrypting context '
                                 'data for performance profiling of operation. '
                                 'This key should be the value of HMAC key '
                                 'configured in osprofiler middleware in '
-                                'glance, it is specified in paste '
+                                'glance, it is specified in glance '
                                 'configuration file at '
-                                '/etc/glance/api-paste.ini and '
-                                '/etc/glance/registry-paste.ini. Without key '
-                                'the profiling will not be triggered even '
-                                'if osprofiler is enabled on server side.')
+                                '/etc/glance/glance-api.conf and '
+                                '/etc/glance/glance-registry.conf. Without '
+                                'key the profiling will not be triggered even '
+                                'if osprofiler is enabled on server side. '
+                                'Defaults to env[OS_PROFILE].')
 
         self._append_global_identity_args(parser, argv)
 
@@ -434,7 +428,6 @@ class OpenStackImagesShell(object):
                 'cacert': args.os_cacert,
                 'cert': args.os_cert,
                 'key': args.os_key,
-                'ssl_compression': args.ssl_compression
             }
         else:
             ks_session = loading.load_session_from_argparse_arguments(args)
